<p align="center">
    <a href="https://github.com/OctoDiary">
        <img src="https://avatars.githubusercontent.com/u/90847608?s=200&v=4" alt="OctoDiary" width="200">
    </a>
    <br>
    <a href="https://github.com/OctoDiary"><b>OctoDiary</b></a>
    •
    <a href="https://t.me/OctoDiary"><b>Telegram-Канал</b></a>
    •
    <a href="https://pypi.org/project/octodiary/"><b>PyPI</b></a>
</p>

# OctoDiary-py
> Неофициальная Python библиотека для использования API: МЭШ / Моя Школа.

<br>

# <img width="30" height="30" src="https://img.icons8.com/external-sbts2018-outline-color-sbts2018/58/external-install-basic-ui-elements-2.3-sbts2018-outline-color-sbts2018.png" alt="external-install-basic-ui-elements-2.3-sbts2018-outline-color-sbts2018"/> Установка

### Установка через GitHub:
``` bash
$ pip3 install https://github.com/OctoDiary/OctoDiary-py/archive/main.zip --upgrade
```

### Стабильная версия от PyPi:
``` bash
$ pip3 install octodiary --upgrade
```
> Для Windows, если не работает `pip3` > используйте `pip`

<br>

# [<img width="40" height="40" src="https://img.icons8.com/fluency/48/python.png" alt="python"/> Использование](Examples.md)
> Вынесено в [отдельный файл](Examples.md)

<br>

# <img width="30" height="30" src="https://img.icons8.com/officel/48/link.png" alt="link"/> Ссылки
- [**OctoDiary**](https://github.com/OctoDiary)
- [**Telegram канал**](https://t.me/OctoDiary)
- [**PyPI**](https://pypi.org/project/octodiary/)
- [**Den4ikSuperOstryyPer4ik**](https://github.com/Den4ikSuperOstryyPer4ik)
- [**bxkr**](https://github.com/bxkr)
- [**Пример использования библиотеки**](Examples.md)
